@@ -1,20 +1,15 @@
 use crate::config::Config;
-use crate::error::{Error, Result};
+use crate::error::{Result};
+use log::{trace};
 use reqwest::header::{AUTHORIZATION, CONTENT_TYPE};
+use reqwest::RequestBuilder;
+
 #[derive(Debug, Clone)]
 pub struct BitGoClient {
     pub endpoint: String,
     pub token: String,
 }
 
-pub fn value_or_error(value: &serde_json::Value, name: &str) -> Result<serde_json::Value> {
-    match value.get(name) {
-        Some(value) => Ok(value.to_owned()),
-        None => Err(Error::InvalidKey {
-            key: name.to_owned(),
-        }),
-    }
-}
 
 impl BitGoClient {
     pub fn new(endpoint: String, token: String) -> Result<Self> {
@@ -27,15 +22,10 @@ impl BitGoClient {
 
     async fn call_api<T: serde::Serialize>(
         &self,
+        builder: RequestBuilder,
         params: &T,
-        request_url: &str,
     ) -> Result<serde_json::Value> {
-        let client = reqwest::Client::builder()
-            .danger_accept_invalid_certs(true)
-            .build()?;
-
-        let response_json: serde_json::Value = client
-            .get(request_url)
+        let response_json: serde_json::Value = builder
             .header(CONTENT_TYPE, "application/json")
             .header(AUTHORIZATION, format!("Bearer {}", self.token))
             .json(params)
@@ -43,7 +33,7 @@ impl BitGoClient {
             .await?
             .json()
             .await?;
-
+        trace!("bitgo api response {:?}", response_json);
         Ok(response_json)
     }
 
@@ -53,7 +43,8 @@ impl BitGoClient {
         params: &T,
     ) -> Result<serde_json::Value> {
         log::trace!("request url {:?}", request_url);
-        self.call_api(params, request_url).await
+        let builder = reqwest::Client::new().get(request_url);
+        self.call_api(builder, params).await
     }
 
     pub async fn post_api<T: serde::Serialize>(
@@ -62,7 +53,8 @@ impl BitGoClient {
         params: &T,
     ) -> Result<serde_json::Value> {
         log::trace!("request url {:?}", request_url);
-        self.call_api(params, request_url).await
+        let builder = reqwest::Client::new().post(request_url);
+        self.call_api(builder, params).await
     }
 
     pub async fn delete_api<T: serde::Serialize>(
@@ -71,6 +63,7 @@ impl BitGoClient {
         params: &T,
     ) -> Result<serde_json::Value> {
         log::trace!("request url {:?}", request_url);
-        self.call_api(params, request_url).await
+        let builder = reqwest::Client::new().delete(request_url);
+        self.call_api(builder, params).await
     }
 }
