@@ -76,6 +76,8 @@ mock! {
             listen_failure_states: bool,
         ) -> Result<serde_json::Value>;
 
+
+
         async fn add_block_webhook(
             &self,
             identifier: &str,
@@ -108,7 +110,6 @@ mock! {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::client::value_or_error;
     use serde_json::json;
 
     #[tokio::test]
@@ -119,8 +120,9 @@ mod tests {
         ));
 
         let v = mock.create_address("any", " any", 0).await.unwrap();
+
         assert_eq!(
-            value_or_error(&v, "address").unwrap().to_owned(),
+            v.get("address").unwrap().to_owned(),
             "2MvrwRYBAuRtPTiZ5MyKg42Ke55W3fZJfZS"
         );
     }
